# ImageGoNord - RGB image to Nordtheme palette

![PyPI - Python Version](https://img.shields.io/pypi/pyversions/image-go-nord)
[![PyPI](https://img.shields.io/pypi/v/image-go-nord)](https://pypi.org/project/image-go-nord/)
[![license](https://img.shields.io/badge/license-MIT-green)](https://github.com/Schrodinger-Hat/ImageGoNord-pip/blob/master/LICENSE)
[![Join the community on Spectrum](https://withspectrum.github.io/badge/badge.svg)](https://spectrum.chat/image-go-nord)

A tool that can convert your rgb images to nordtheme palette.

This repository is a python package that can convert any sort of image into a [nordtheme](https://github.com/arcticicestudio/nord) palette image.

You can find a demo on [the website](https://ign.schrodinger-hat.it) for testing out the package.

We build also a little API hosted on Heroku to give to anyone the change to test it out by theirself. You can find the documentation on the website too.

The main repository of this whole project is [ImageGoNord](https://github.com/Schrodinger-Hat/ImageGoNord).

### Documentation

You can find the [documentation into this repository](https://github.com/Schrodinger-Hat/ImageGoNord-pip/tree/master/docs) and also on the website.

<!--
@TODO
- Describe very briefly but clearly what the project does.
- State if it is out-of-the-box user-friendly, so it’s clear to the user.
- List its most useful/innovative/noteworthy features.
- State its goals/what problem(s) it solves.
- Note and briefly describe any key concepts (technical, philosophical, or both) important to the user’s understanding.
- Link to any supplementary blog posts or project main pages.
- Note its development status.
- If possible, include screenshots and demo videos.
-->

### Inspiration

We are in love with Nordtheme, that is why we created this repository.

[![Nord Color Palette Overview](https://raw.githubusercontent.com/arcticicestudio/nord-docs/develop/assets/images/nord/repository-color-palettes.svg?sanitize=true)](https://www.nordtheme.com/docs/colors-and-palettes)

Our goal is to make a shortcut to convert anything into this theme, by starting from the images.
<br>An example could be an awesome wallpaper converted into the Nordtheme palette.

We checked the commnunity and we did not find anything similar or any project that can accomplish this task. So, here we are.

### What you can do with this package

You can convert any image into the nord palette (or others). Here are some examples:

**Original**

[![Original](https://raw.githubusercontent.com/Schrodinger-Hat/ImageGoNord-pip/master/images/test.jpg)](https://raw.githubusercontent.com/Schrodinger-Hat/ImageGoNord-pip/master/images/test.jpg)


**Processed with avg algorithm**

[![Original](https://raw.githubusercontent.com/Schrodinger-Hat/ImageGoNord-pip/master/images/test-average.jpg)](https://raw.githubusercontent.com/Schrodinger-Hat/ImageGoNord-pip/master/images/test-average.jpg)


-----


**Original**

[![Original](https://raw.githubusercontent.com/Schrodinger-Hat/ImageGoNord-pip/master/images/test-profile.jpg)](https://raw.githubusercontent.com/Schrodinger-Hat/ImageGoNord-pip/master/images/test-profile.jpg)


**Processed with avg algorithm**

[![Original](https://raw.githubusercontent.com/Schrodinger-Hat/ImageGoNord-pip/master/images/test-profile-average.jpg)](https://raw.githubusercontent.com/Schrodinger-Hat/ImageGoNord-pip/master/images/test-profile-average.jpg)

### Core Technical Concepts

We are using the PIL because it is the most simple library and it is very useful when you need to manipolate some images.

Our goal is also to make this project open source and maintainable by the community. We would love to.

*We believe in the open source community.*

### Getting Started

Getting it from PIP

```
pip install image-go-nord
```

Then you can use [some example](https://github.com/Schrodinger-Hat/ImageGoNord-pip/tree/master/docs/example) to getting started properly!

### Contributing
- Follow the contributor guidelines
- Follow the code style / requirements
- Format for commit messages

### TODO
- Testing
- Improvements on image quality and supporting any image format
- Make contributing guidelines

# Authors

[TheJoin95](https://github.com/TheJoin95) & [Wabri](https://github.com/Wabri)

**NOTE**: we are not (yet) affiliated with the Nordtheme or [Arcticicestudio](https://github.com/arcticicestudio).

# Credits

[Nordtheme](https://www.nordtheme.com/)

### License

[MIT license](https://github.com/Schrodinger-Hat/ImageGoNord-pip/blob/master/LICENSE)
